Improve this Doc

# Error: $interpolate:unsafe
MessageFormat extensions not allowed in secure context

    Use of select/plural MessageFormat syntax is currently disallowed in a secure context ({0}).  At line {1}, column {2} of text “{3}”

## Description

You have attempted to use a MessageFormat extension in your interpolation expression that is marked as a secure context. For security purposes, this is not supported.

Read more about secure contexts at Strict Contextual Escaping (SCE) and about the MessageFormat extensions at Angular i18n MessageFormat.